==> jc-1.4.0.tar.gz: soot/jimple/parser/node/X2PCaseStmt.h <==
// public final class soot.jimple.parser.node.X2PCaseStmt

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 487c744bf3662e57 soot_jimple_parser_node_X2PCaseStmt
// @dep_class 3a9883ba52a1017c soot_jimple_parser_node_XPCaseStmt

// header file dependencies
// @dep_header soot_jimple_parser_node_XPCaseStmt

#include "soot/jimple/parser/node/XPCaseStmt.h"

#ifndef _JC_soot_jimple_parser_node_X2PCaseStmt_H_
#define _JC_soot_jimple_parser_node_X2PCaseStmt_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_PCaseStmt$object;
struct _jc_soot_jimple_parser_node_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_X2PCaseStmt$sub_refs	_jc_soot_jimple_parser_node_X2PCaseStmt$sub_refs;
typedef struct _jc_soot_jimple_parser_node_X2PCaseStmt$sub_nonrefs	_jc_soot_jimple_parser_node_X2PCaseStmt$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_X2PCaseStmt$refs	_jc_soot_jimple_parser_node_X2PCaseStmt$refs;
typedef struct _jc_soot_jimple_parser_node_X2PCaseStmt$nonrefs	_jc_soot_jimple_parser_node_X2PCaseStmt$nonrefs;
typedef struct _jc_soot_jimple_parser_node_X2PCaseStmt$object	_jc_soot_jimple_parser_node_X2PCaseStmt$object;

typedef const struct _jc_soot_jimple_parser_node_X2PCaseStmt$vmethods	_jc_soot_jimple_parser_node_X2PCaseStmt$vmethods;
typedef const struct _jc_soot_jimple_parser_node_X2PCaseStmt$vtable	_jc_soot_jimple_parser_node_X2PCaseStmt$vtable;
typedef const struct _jc_soot_jimple_parser_node_X2PCaseStmt$vtype	_jc_soot_jimple_parser_node_X2PCaseStmt$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_X2PCaseStmt$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_X2PCaseStmt$object *);
extern void _jc_soot_jimple_parser_node_X2PCaseStmt$method$_init$33b0a44e4d1bf614(_jc_env *, struct _jc_soot_jimple_parser_node_X2PCaseStmt$object *, struct _jc_soot_jimple_parser_node_PCaseStmt$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_X2PCaseStmt$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_X2PCaseStmt$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_X2PCaseStmt$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_X2PCaseStmt$object *);
extern struct _jc_soot_jimple_parser_node_PCaseStmt$object *_jc_soot_jimple_parser_node_X2PCaseStmt$method$getPCaseStmt$f7ead6f3c1710e77(_jc_env *, struct _jc_soot_jimple_parser_node_X2PCaseStmt$object *);
extern void _jc_soot_jimple_parser_node_X2PCaseStmt$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_X2PCaseStmt$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_X2PCaseStmt$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_X2PCaseStmt$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_X2PCaseStmt$method$setPCaseStmt$d267830565504671(_jc_env *, struct _jc_soot_jimple_parser_node_X2PCaseStmt$object *, struct _jc_soot_jimple_parser_node_PCaseStmt$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_X2PCaseStmt$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_X2PCaseStmt$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_X2PCaseStmt$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_X2PCaseStmt$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_X2PCaseStmt$method_info$getPCaseStmt$f7ead6f3c1710e77;
extern _jc_method _jc_soot_jimple_parser_node_X2PCaseStmt$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_X2PCaseStmt$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_X2PCaseStmt$method_info$setPCaseStmt$d267830565504671;
extern _jc_method _jc_soot_jimple_parser_node_X2PCaseStmt$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_X2PCaseStmt$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PCaseStmt$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PCaseStmt$object *);
	struct _jc_soot_jimple_parser_node_PCaseStmt$object	*(*getPCaseStmt$f7ead6f3c1710e77)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PCaseStmt$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PCaseStmt$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PCaseStmt$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setPCaseStmt$d267830565504671)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PCaseStmt$object *, struct _jc_soot_jimple_parser_node_PCaseStmt$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PCaseStmt$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_X2PCaseStmt$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_XPCaseStmt$vmethods	soot_jimple_parser_node_XPCaseStmt;
	_jc_soot_jimple_parser_node_X2PCaseStmt$vmethods	soot_jimple_parser_node_X2PCaseStmt;
};

// Vtype
struct _jc_soot_jimple_parser_node_X2PCaseStmt$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_X2PCaseStmt$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_X2PCaseStmt$sub_refs {
	struct _jc_soot_jimple_parser_node_PCaseStmt$object	*__5fpCaseStmt__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_X2PCaseStmt$refs {
    _jc_soot_jimple_parser_node_X2PCaseStmt$sub_refs	soot_jimple_parser_node_X2PCaseStmt;
    _jc_soot_jimple_parser_node_XPCaseStmt$sub_refs	soot_jimple_parser_node_XPCaseStmt;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_X2PCaseStmt$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_X2PCaseStmt$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_XPCaseStmt$sub_nonrefs	soot_jimple_parser_node_XPCaseStmt;
    _jc_soot_jimple_parser_node_X2PCaseStmt$sub_nonrefs	soot_jimple_parser_node_X2PCaseStmt;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_X2PCaseStmt$object {
	_jc_soot_jimple_parser_node_X2PCaseStmt$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_X2PCaseStmt$vtype	*vtype;
	_jc_soot_jimple_parser_node_X2PCaseStmt$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_X2PCaseStmt$vtype _jc_soot_jimple_parser_node_X2PCaseStmt$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_X2PCaseStmt, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_X2PCaseStmt$class_object;

#endif	/* _JC_soot_jimple_parser_node_X2PCaseStmt_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/X2PCaseStmt.h <==
// public final class soot.jimple.parser.node.X2PCaseStmt

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 487c744bf3662e57 soot_jimple_parser_node_X2PCaseStmt
// @dep_class 3a9883ba52a1017c soot_jimple_parser_node_XPCaseStmt

// header file dependencies
// @dep_header soot_jimple_parser_node_XPCaseStmt

#include "soot/jimple/parser/node/XPCaseStmt.h"

#ifndef _JC_soot_jimple_parser_node_X2PCaseStmt_H_
#define _JC_soot_jimple_parser_node_X2PCaseStmt_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_PCaseStmt$object;
struct _jc_soot_jimple_parser_node_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_X2PCaseStmt$sub_refs	_jc_soot_jimple_parser_node_X2PCaseStmt$sub_refs;
typedef struct _jc_soot_jimple_parser_node_X2PCaseStmt$sub_nonrefs	_jc_soot_jimple_parser_node_X2PCaseStmt$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_X2PCaseStmt$refs	_jc_soot_jimple_parser_node_X2PCaseStmt$refs;
typedef struct _jc_soot_jimple_parser_node_X2PCaseStmt$nonrefs	_jc_soot_jimple_parser_node_X2PCaseStmt$nonrefs;
typedef struct _jc_soot_jimple_parser_node_X2PCaseStmt$object	_jc_soot_jimple_parser_node_X2PCaseStmt$object;

typedef const struct _jc_soot_jimple_parser_node_X2PCaseStmt$vmethods	_jc_soot_jimple_parser_node_X2PCaseStmt$vmethods;
typedef const struct _jc_soot_jimple_parser_node_X2PCaseStmt$vtable	_jc_soot_jimple_parser_node_X2PCaseStmt$vtable;
typedef const struct _jc_soot_jimple_parser_node_X2PCaseStmt$vtype	_jc_soot_jimple_parser_node_X2PCaseStmt$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_X2PCaseStmt$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_X2PCaseStmt$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_X2PCaseStmt$method$_init$33b0a44e4d1bf614(_jc_env *, struct _jc_soot_jimple_parser_node_X2PCaseStmt$object *, struct _jc_soot_jimple_parser_node_PCaseStmt$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_X2PCaseStmt$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_X2PCaseStmt$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_X2PCaseStmt$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_X2PCaseStmt$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_PCaseStmt$object *_jc_soot_jimple_parser_node_X2PCaseStmt$method$getPCaseStmt$f7ead6f3c1710e77(_jc_env *, struct _jc_soot_jimple_parser_node_X2PCaseStmt$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_X2PCaseStmt$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_X2PCaseStmt$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_X2PCaseStmt$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_X2PCaseStmt$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_X2PCaseStmt$method$setPCaseStmt$d267830565504671(_jc_env *, struct _jc_soot_jimple_parser_node_X2PCaseStmt$object *, struct _jc_soot_jimple_parser_node_PCaseStmt$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_X2PCaseStmt$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_X2PCaseStmt$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_X2PCaseStmt$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_X2PCaseStmt$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_X2PCaseStmt$method_info$getPCaseStmt$f7ead6f3c1710e77;
extern _jc_method _jc_soot_jimple_parser_node_X2PCaseStmt$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_X2PCaseStmt$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_X2PCaseStmt$method_info$setPCaseStmt$d267830565504671;
extern _jc_method _jc_soot_jimple_parser_node_X2PCaseStmt$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_X2PCaseStmt$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PCaseStmt$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PCaseStmt$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_PCaseStmt$object	*(*getPCaseStmt$f7ead6f3c1710e77)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PCaseStmt$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PCaseStmt$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PCaseStmt$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setPCaseStmt$d267830565504671)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PCaseStmt$object *, struct _jc_soot_jimple_parser_node_PCaseStmt$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PCaseStmt$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_X2PCaseStmt$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_XPCaseStmt$vmethods	soot_jimple_parser_node_XPCaseStmt;
	_jc_soot_jimple_parser_node_X2PCaseStmt$vmethods	soot_jimple_parser_node_X2PCaseStmt;
};

// Vtype
struct _jc_soot_jimple_parser_node_X2PCaseStmt$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_X2PCaseStmt$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_X2PCaseStmt$sub_refs {
	struct _jc_soot_jimple_parser_node_PCaseStmt$object	*__5fpCaseStmt__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_X2PCaseStmt$refs {
    _jc_soot_jimple_parser_node_X2PCaseStmt$sub_refs	soot_jimple_parser_node_X2PCaseStmt;
    _jc_soot_jimple_parser_node_XPCaseStmt$sub_refs	soot_jimple_parser_node_XPCaseStmt;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_X2PCaseStmt$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_X2PCaseStmt$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_XPCaseStmt$sub_nonrefs	soot_jimple_parser_node_XPCaseStmt;
    _jc_soot_jimple_parser_node_X2PCaseStmt$sub_nonrefs	soot_jimple_parser_node_X2PCaseStmt;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_X2PCaseStmt$object {
	_jc_soot_jimple_parser_node_X2PCaseStmt$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_X2PCaseStmt$vtype	*vtype;
	_jc_soot_jimple_parser_node_X2PCaseStmt$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_X2PCaseStmt$vtype _jc_soot_jimple_parser_node_X2PCaseStmt$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_X2PCaseStmt, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_X2PCaseStmt$class_object;

#endif	/* _JC_soot_jimple_parser_node_X2PCaseStmt_H_ */
